summaryrefslogtreecommitdiff
path: root/keyboards/handwired/6macro
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/handwired/6macro')
-rw-r--r--keyboards/handwired/6macro/config.h1
-rw-r--r--keyboards/handwired/6macro/keymaps/osu/keymap.c6
2 files changed, 3 insertions, 4 deletions
diff --git a/keyboards/handwired/6macro/config.h b/keyboards/handwired/6macro/config.h
index 7fe3be6556..1e8c296855 100644
--- a/keyboards/handwired/6macro/config.h
+++ b/keyboards/handwired/6macro/config.h
@@ -26,7 +26,6 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
/* pinout - DON'T CHANGE */
#define MATRIX_ROW_PINS { B3, B4 }
#define MATRIX_COL_PINS { B0, B1, B2 }
-#define UNUSED_PINS
/* COL2ROW, ROW2COL*/
#define DIODE_DIRECTION COL2ROW
diff --git a/keyboards/handwired/6macro/keymaps/osu/keymap.c b/keyboards/handwired/6macro/keymaps/osu/keymap.c
index ffed7d909f..c3ee0f2ccf 100644
--- a/keyboards/handwired/6macro/keymaps/osu/keymap.c
+++ b/keyboards/handwired/6macro/keymaps/osu/keymap.c
@@ -33,7 +33,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* ,-----------------------.
* |RGB_TOG|RGBMOD+| |
* |-------+-------+-------|
* |RGBHUE+|RGBBRI+|Spec FN| Hold along with previous to access special funtions (RESET)
* `-------+-------+-------'
*/
[1] = LAYOUT(
@@ -43,13 +43,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
/* LAYER 2
* ,-----------------------.
- * | RESET |RGBMOD-| |
+ * | QK_BOOT |RGBMOD-| |
* |-------+-------+-------|
* |RGBHUE-|RGBBRI-| |
* `-------+-------+-------'
*/
[2] = LAYOUT(
- RESET, RGB_RMOD, KC_NO, \
+ QK_BOOT, RGB_RMOD, KC_NO, \
RGB_HUD, RGB_VAD, KC_TRNS \
)
@@ -33,7 +33,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |RGB_TOG|RGBMOD+| |
* |-------+-------+-------|
- * |RGBHUE+|RGBBRI+|Spec FN| Hold along with previous to access special funtions (RESET)
+ * |RGBHUE+|RGBBRI+|Spec FN| Hold along with previous to access special funtions (QK_BOOT)
* `-------+-------+-------'
*/